# flake8: NOQA
from .string_edit import StringEdit

__copy__right__   = "Coopyright (C) 2018 uki.uki.satoshi"
__version__       = "1.0.5"
__license__       = "MIT"
__author__        = "uki.uki.satoshi"
__author_email__  = "39693776+ukiuki-satoshi@users.noreply.github.com"
__url__           = "https://github.com/ukiuki-satoshi/visedit"

__all__ = ["StringEdit", ]
